@@ -396,7 +396,7 @@ void GLTestWidget::mouseMoveEvent(QMouseEvent * e) {
   if (!depthbuffer) return;
 
 #ifdef WIN32
-  assert(mousepressed);
+//   assert(mousepressed);
 #endif
 
   if (e->state() & Qt::LeftButton && old_valid) {
