@@ -39,13 +39,20 @@ int main( int argc, char ** argv )
   readXMLConfig(QDir::homeDirPath()+QDir::separator()+QString(".earth3d")+QDir::separator());
 #endif
 
+  loadCachedAttributes();
+
+  // init cache
+  if (getAttribute("usecache", "true")=="true") {
+    fileCache.setCacheLocation(getAttribute("cachelocation", QDir::homeDirPath()+QDir::separator()+QString(".earth3d")+QDir::separator()+QString("cache")));
+  }
+
   FormView w;
   if (argc>1) {
     w.setServiceListLocation(argv[1]);
   }
   w.show();
   a.connect( &a, SIGNAL( lastWindowClosed() ), &a, SLOT( quit() ) );
-  w.statusBar()->message("Program started, Version 1.0.3.");
+  w.statusBar()->message("Program started, Version 1.0.4.");
   
   return a.exec();
 }
