@@ -20,7 +20,7 @@ class URLDownload : public ProxyUrlOperator, public StopableDownload {
   virtual void finished(QNetworkOperation *qno);
 
  public:
-  URLDownload(const char *url, DataReceivedListener *drl, void *userdata);
+  URLDownload(const char *url, DataReceivedListener *drl, void *userdata, bool allowCache=true);
   virtual ~URLDownload();
 
   virtual void run();
